@@ -8,11 +8,15 @@ from webdriverplus.selectors import SelectorMixin
 from webdriverplus.utils import get_terminal_size
 from webdriverplus.wrappers import Style, Attributes, Size, Location
 
+try:
+    from urllib2 import quote
+except ImportError:
+    from urllib.request import quote
+
 import os
 import sys
 
 
-
 # http://stackoverflow.com/questions/6157929/how-to-simulate-mouse-click-using-javascript/6158050#6158050
 def simulate_event(event, **options):
     return """
@@ -158,6 +162,10 @@ class WebElement(SelectorMixin, _WebElement):
     @property
     def value(self):
         return self.get_attribute('value')
+    
+    @value.setter
+    def value(self, value):
+        self._parent.execute_script('arguments[0].value=unescape(decodeURI("%s"));' % quote(value), self)
 
     @deprecated_property
     def is_checked(self):
@@ -263,7 +271,11 @@ class WebElement(SelectorMixin, _WebElement):
 
     def move_to_and_click(self, x=0, y=0):
         # self._parent.execute_script(simulate_event('mouseover'), self)
-        ActionChains(self._parent).move_to_element_with_offset(super(WebElement, self), x, y).click().perform()
+        if x and y:
+            action_chains = ActionChains(self._parent).move_to_element_with_offset(super(WebElement, self), x, y)
+        else:
+            action_chains = ActionChains(self._parent).move_to_element(super(WebElement, self))
+        action_chains.click().perform()
         return self
 
     def check(self):
@@ -283,7 +295,8 @@ class WebElement(SelectorMixin, _WebElement):
         self.send_keys(*args)
 
     def select_option(self, value=None, text=None, index=None):
-        if len(filter(lambda x: x is not None, (value, text, index))) != 1:
+        # Python3 filter -> list(filter)
+        if len(list(filter(None, (value, text, index)))) != 1:
             raise ValueError("You must supply exactly one of (value, text, index) kwargs")
 
         select = Select(self)
@@ -295,7 +308,7 @@ class WebElement(SelectorMixin, _WebElement):
             select.select_by_index(index)
 
     def deselect_option(self, value=None, text=None, index=None):
-        if len(filter(lambda x: x is not None, (value, text, index))) != 1:
+        if len(list(filter(None, (value, text, index)))) != 1:
             raise ValueError("You must supply exactly one of (value, text, index) kwargs")
 
         select = Select(self)
